darkhistory.physics.dtdz — DarkHistory documentation

# darkhistory.physics.dtdz

`darkhistory.physics.` `dtdz`(rs, H0=2.1748869673182562e-18, omega_m=0.3175, omega_rad=8e-05, omega_lambda=0.6825)

  dt/dz in s.

  Parameters: | rs : float The redshift of interest. H0 : float The Hubble parameter today, default value H0. omega_m : float, optional Omega matter today, default value omega_m. omega_rad : float, optional Omega radiation today, default value omega_rad. omega_lambda : float, optional Omega dark energy today, default value omega_lambda.
  Returns: | float

#### Previous topic

darkhistory.physics.hubble

#### Next topic

darkhistory.physics.TCMB

### This Page

Show Source